@@ -9,7 +9,7 @@ use Storable qw< dclone >;
 use Data::Embed::File;
 use Data::Embed::Util qw< :constants unescape >;
 
-our $VERSION = '0.30'; # make indexer happy
+our $VERSION = '0.32'; # make indexer happy
 
 sub new {
    my $package = shift;
@@ -32,8 +32,9 @@ sub new {
       DEBUG $package,
         ': input is a file or other thing that can be open-ed';
       $self->{filename} = $input;
-      open $self->{fh}, '<:raw', $input
+      open $self->{fh}, '<', $input
         or LOGCROAK "open('$input'): $OS_ERROR";
+      binmode $self->{fh}, ':raw';
    } ## end else [ if (ref($input) eq 'GLOB')]
 
    return $self;
@@ -45,7 +46,7 @@ sub files {
 }
 
 sub prefix {
-   return shift->{_prefix};
+   return shift->_ensure_index()->{_prefix};
 }
 
 sub reset {
